@@ -49,6 +49,7 @@ public:
     {
         renf_clear(nf);
         renf_init_set(nf, k.nf);
+        gen_name = k.gen_name;
         return *this;
     }
 
@@ -143,8 +144,9 @@ public:
     __RENFXX_construct(unsigned long int, assign_ui)
     __RENFXX_construct(mpz_class&, assign_mpz_class)
     __RENFXX_construct(mpq_class&, assign_mpq_class)
-    explicit __RENFXX_construct(std::vector<mpz_class>&, assign_mpz_vector);
-    explicit __RENFXX_construct(std::vector<mpq_class>&, assign_mpq_vector);
+    __RENFXX_construct(fmpq_poly_t, assign_fmpq_poly)
+    explicit __RENFXX_construct(std::vector<mpz_class>&, assign_mpz_vector)
+    explicit __RENFXX_construct(std::vector<mpq_class>&, assign_mpq_vector)
     explicit __RENFXX_construct(std::string&, assign_string)
     #undef __constructor
 
@@ -168,6 +170,9 @@ public:
     mpq_class get_rational(void) const;
     std::vector<mpz_class> get_num_vector(void) const;
 
+    // gcd of numerator
+    mpz_class num_content() const noexcept;
+
     // floor, ceil, round, approximation
     mpz_class floor() const;
     mpz_class ceil() const;
@@ -394,7 +399,7 @@ inline renf_elem_class renf_class::gen()
 
 inline slong renf_class::degree()
 {
-    return nf == NULL ? 1 : nf_degree(nf->nf);
+    return nf_degree(nf->nf);
 }
 
 
@@ -487,11 +492,11 @@ inline void renf_elem_class::assign_mpz_vector(const std::vector<mpz_class>& v)
 
     if (nf == nullptr)
         throw std::invalid_argument("renf_elem_class: can not assign from std::vector<mpz_class> if number field not set");
-    if (v.size() > nf->degree())
+    if ((long) v.size() > nf->degree())
         throw std::invalid_argument("vector too long");
 
     fmpq_poly_init(p);
-    for (slong i = 0; i < v.size(); i++)
+    for (slong i = 0; i < (long) v.size(); i++)
         fmpq_poly_set_coeff_mpz(p, i, v[i].__get_mp());
     assign_fmpq_poly(p);
     fmpq_poly_clear(p);
@@ -503,11 +508,11 @@ inline void renf_elem_class::assign_mpq_vector(const std::vector<mpq_class>& v)
 
     if (nf == nullptr)
         throw std::invalid_argument("renf_elem_class: can not assign from std::vector<mpz_class> if number field not set");
-    if (v.size() > nf->degree())
+    if ((long) v.size() > nf->degree())
         throw std::invalid_argument("vector too long");
 
     fmpq_poly_init(p);
-    for (slong i = 0; i < v.size(); i++)
+    for (slong i = 0; i < (long) v.size(); i++)
         fmpq_poly_set_coeff_mpq(p, i, v[i].__get_mp());
     assign_fmpq_poly(p);
     fmpq_poly_clear(p);
